/* 
 * tclMacConsole.c --
 *
 *	This file contains Macintosh-specific procedures for the notifier,
 *	which is the lowest-level part of the Tcl event loop.  This file
 *	works together with ../generic/tclNotify.c.
 *
 * Copyright (c) 1995-1996 Sun Microsystems, Inc.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

static char sccsid[] = "@(#) tclMacConsole.c 1.6 96/01/12 22:20:00";

#include "tclInt.h"
#include "tclPort.h"
#include <Events.h>
#include <SIOUX.h> 

#if defined(THINK_C)
#   include <console.h>
#elif defined(__MWERKS__)
/*
 * Selected includes from GUSI.h.  We can't
 * include the entire file as it conflicts with
 * other include files.
 */
typedef enum {
	GUSI_SpinHook,	/* A GUSISpinFn, to be called when a call blocks */
	GUSI_ExecHook   /* Boolean (*hook)(const GUSIFileRef & ref), 
			 * decides if file is executable */
} GUSIHookCode;

typedef enum spin_msg {
	SP_MISC,				/* some weird thing, usually just return immediately if you get this */
	SP_SELECT,			/* in a select call */
	SP_NAME,				/* getting a host by name */
	SP_ADDR,				/* getting a host by address */
	SP_STREAM_READ,	/* Stream read call */
	SP_STREAM_WRITE,	/* Stream write call */
	SP_DGRAM_READ,		/* Datagram read call */
	SP_DGRAM_WRITE,	/* Datagram write call */
	SP_SLEEP,			/* sleeping, passes ticks left to sleep */
	SP_AUTO_SPIN		/* Autospin, passes argument to SpinCursor */
} spin_msg;

void GUSIDefaultSetup();
typedef void (*GUSIHook)(void);
void GUSISetHook(GUSIHookCode code, GUSIHook hook);
#   include <SIOUX.h>
short InstallConsole _ANSI_ARGS_((short fd));
static int GUSISpinFunction _ANSI_ARGS_((spin_msg msg, long param));
#endif

int 	TclMacConvertEvent _ANSI_ARGS_((EventRecord *eventPtr));

/*
 *----------------------------------------------------------------------
 *
 * TclMacConvertEvent --
 *
 *	This function handles a macintosh event.  In a Tcl interperter
 *	all we need to do is pass the event to SIOUX and we are done.
 *
 * Results:
 *	True if event was handled, false otherwise.
 *
 * Side effects:
 *	Passes the event to SIOUX.
 *
 *----------------------------------------------------------------------
 */

int
TclMacConvertEvent(eventPtr)
    EventRecord *eventPtr;
{
    return SIOUXHandleOneEvent(eventPtr);
}

/*
 *----------------------------------------------------------------------
 *
 * TclMacConsoleInit --
 *
 *	This procedure calls initalization routines to set up a simple
 *	console on a Macintosh.  This is necessary as the Mac doesn't
 *	have a stdout & stderr by default.
 *
 * Results:
 *	Returns TCL_OK if everything went fine.  If it didn't the 
 *	application should probably fail.
 *
 * Side effects:
 *	Inits the appropiate console package.
 *
 *----------------------------------------------------------------------
 */

int
TclMacConsoleInit()
{
#if defined(THINK_C)

    /* Set options for Think C console package */
    /* The console package calls the Mac init calls */
    console_options.pause_atexit = 0;
    console_options.title = "\pTcl Interpreter";
		
#elif defined(__MWERKS__)

    GUSIDefaultSetup();
    GUSISetHook(GUSI_SpinHook, (GUSIHook) GUSISpinFunction);
    
    /* Set options for CodeWarrior SIOUX package */
    SIOUXSettings.autocloseonquit = true;
    SIOUXSettings.showstatusline = true;
    SIOUXSettings.asktosaveonclose = false;
    InstallConsole(0);
    SIOUXSetTitle("\pTcl Interpreter");
		
#elif defined(applec)

    /* Init packages used by MPW SIOW package */
    InitGraf((Ptr)&qd.thePort);
    InitFonts();
    InitWindows();
    InitMenus();
    TEInit();
    InitDialogs(nil);
    InitCursor();
		
#endif

    /* No problems with initialization */
    return TCL_OK;
}

/*
 *----------------------------------------------------------------------
 *
 * GUSISpinFunction --
 *
 *	Spins.
 *
 * Results:
 *	Returns .
 *
 * Side effects:
 *	None.
 *
 *----------------------------------------------------------------------
 */

static int
GUSISpinFunction(msg, param)
    spin_msg msg;
    long param;
{
    EventRecord ev;
    
    WaitNextEvent(0, &ev, 0, NULL);
    return 0;
}

/*
 *----------------------------------------------------------------------
 *
 * TclGeneratePollingEvents --
 *
 *	In Tcl we never have polled events.
 *
 * Results:
 *	Always returns false.  
 *
 * Side effects:
 *	None.
 *
 *----------------------------------------------------------------------
 */

int
TclGeneratePollingEvents()
{
    return 0;
}
